Estimates the proportion of ASC sites (significant in Cell Type A) that still show a non-zero effect in Cell Type B, using the Beta-Binomial posterior and ashR.

estimateSharedImbalance(dsObjA, dsObjB, fdrCutoff = 0.01)

Arguments

dsObjA

DsASC object for Cell Type A.

dsObjB

DsASC object for Cell Type B.

fdrCutoff

Numeric. FDR threshold for defining significance in Cell Type A (Default 0.01).

Value

A list with the ashR model output and the estimated proportion of shared effects.