scan a directory containing fastq files and create a sample annotation table from the file names
fastqDirToTable(fqDir, tabFn = NULL, pat = "")
Arguments
- fqDir
string specifying a directory with fastq files
- tabFn
filename specifying the where the table should be written to. If NULL (default), the table will just be returned
as data frame
- pat
(optional) regular expression that fastq file names have to pass
Value
data frame of parsed annotation