Retrieve sample summary statistics from the output a snakeATAC pipline run
getSampleMetrics.snakeATAC(sampleAnnot, snakeDir, withPeaks = TRUE)
Arguments
- sampleAnnot
data.frame specifying the sample annotation table. Must have valid rownames corresponding to the sample ids used in
the snakeAtac filenames
- snakeDir
snakeATAC base directory (where the files are located)
- withPeaks
flag indicating whether to output peak statistics
Value
data.frame containing sample summary statistics. the original sample annotation table will be appended to the summary output