Remove the specified sites or regions from an object
# S4 method for class 'DsAcc'
removeRegions(.object, indices, type)DsAcc object
a vector of indices of sites/regions to be removed. Can be numeric, integer or logical.
character string specifying a name for the region type (sefault: sites)
a new DsAcc object with sites/regions removed