R/DsASC-class.R
estimateSharedImbalance.RdEstimates the proportion of ASC sites (significant in Cell Type A) that still show a non-zero effect in Cell Type B, using the Beta-Binomial posterior and ashR.
estimateSharedImbalance(dsObjA, dsObjB, fdrCutoff = 0.01)A list with the ashR model output and the estimated proportion of shared effects.